magql
=====

Magql is a `GraphQL`_ framework for Python. It generates a
full-featured, customizable GraphQL API for your data. It's pronounced
"magical", and it is!

-   Queries

    -   Index/list with filtering, sorting, and paging.
    -   Detail
    -   Global search

-   Mutations

    -   Create with required and optional fields.
    -   Update any set of fields.
    -   Delete, with "check delete" query to return affected related objects.

-   Discrete, overridable steps instead of a single resolve function.
-   Input validation and error messages per field.

.. _GraphQL: https://graphql.org/
